@@ -18,13 +18,18 @@ urpm::lock - urpm/rpm DB locking related routines for urpmi
 
 =head1 DESCRIPTION
 
-=head1 CLASS FUNCTIONS
-
 =over
 
+=cut 
+
+
+################################################################################
+#- class functions
+
+
 =item rpm_db($urpm, $b_exclusive, %options)
 
-Lock rpm DB.
+Lock urpmi DB.
 
 Lock policy concerning chroot : lock rpm db in chroot
 
@@ -53,29 +58,11 @@ sub urpmi_db {
     urpm::lock->new($urpm, "$urpm->{statedir}/.LOCK", 'urpmi', $b_exclusive, %options);
 }
 
-=back
 
-=head1 METHODS
-
-=over
-
-=item new($_class, $urpm, $file, $db_name, $b_exclusive, %options)
-
-Create a new lock.
-You don't want to use it directly. Either use urpmi_db() or rpm_db().
-
-Options:
-
-=over 4
-
-=item * nofatal
-
-=item * wait
-
-=back
-
-=cut
+################################################################################
+#- methods
 
+# (options: nofatal, wait)
 sub new {
     my ($_class, $urpm, $file, $db_name, $b_exclusive, %options) = @_;
     
@@ -134,14 +121,6 @@ sub _lock {
     $lock->{exclusive} = $b_exclusive;
 }
 
-
-=item unlock($lock)
-
-Free a lock.
-
-=cut
-
-
 sub unlock {
     my ($lock) = @_;
     $lock->{fh} or warn "lock $lock->{db_name} already released\n", return;
@@ -158,6 +137,7 @@ sub DESTROY {
     my ($lock) = @_;
     unlock($lock) if $lock->{fh};
 }
+__END__
 
 =back
 
@@ -167,6 +147,4 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
-
 =cut
